// menus

@menus-bg: #363B3F;

@menus-link-color: #FFF;
@menus-link-hover-color: #FFF;

@menus-top-elem-hover-bg: #E14D43;

@menus-icon-color: #F1F2F3;
@menus-icon-hover-color: #FFF;

@menus-top-elem-current-color: #FFF;
@menus-top-elem-current-bg: #E14D43;

@submenus-bg: #26292C;

@submenus-link-color: #C2C4C5;
@submenus-link-hover-color: #E14D43;

@submenus-current-link-color: #FFF;

@submenus-head-color: #C2C4C5;

