{% load i18n admin_urls %}
<div id="bottombar">
{% if show_save %}<button title="{% trans 'Save' %}" type="submit" name="_save"><i class="fa fa-lg fa-floppy-o"></i><i class="fa fa-caret-right"></i>{% if is_popup %}<i class="fa fa-lg fa-times"></i>{% else %}<i class="fa fa-lg fa-list-alt"></i>{% endif %} <span class="text">{% trans 'Save' %}</span></button>{% endif %}
{% if show_save_as_new %}<button title="{% trans 'Save as new' %}" type="submit" name="_saveasnew"><i class="fa fa-lg fa-floppy-o"></i><i class="fa fa-caret-right"></i><i class="fa fa-lg fa-files-o"></i> <span class="text">{% trans 'Save as new' %}</span></button>{%endif%}
{% if show_save_and_add_another %}<button title="{% trans 'Save and add another' %}" type="submit" name="_addanother"><i class="fa fa-lg fa-floppy-o"></i><i class="fa fa-caret-right"></i><i class="fa fa-lg fa-plus-square-o"></i> <span class="text">{% trans 'Save and add another' %}</span></button>{% endif %}
{% if show_save_and_continue %}<button title="{% trans 'Save and continue editing' %}" type="submit" name="_continue"><i class="fa fa-lg fa-floppy-o"></i><i class="fa fa-caret-right"></i><i class="fa fa-lg fa-pencil-square-o"></i> <span class="text">{% trans 'Save and continue editing' %}</span></button>{% endif %}
{% if show_delete_link %}
    {% url opts|admin_urlname:'delete' original.pk|admin_urlquote as delete_url %}
    <a title="{% trans "Delete" %}" href="{% add_preserved_filters delete_url %}" class="button deletelink"><i class="fa fa-lg fa-question"></i><i class="fa fa-caret-right"></i><i class="fa fa-trash-o fa-lg"></i> <span class="text">{% trans "Delete" %}</span></a>
{% endif %}
</div>
