#content {
  .button,
  input[type="submit"],
  input[type="button"],
  button[type="submit"],
  .submit-row input {
    .box-shadow(0 1px 0 rgba(255, 255, 255, 0.3) inset, 0 1px 0 rgba(0, 0, 0, 0.08););
    .border-radius(2px);
    border-style: solid;
    border-width: 1px;
    cursor: pointer;
    display: inline-block;
    font-size: 13px;
    height: 28px;
    line-height: 26px;
    margin: 0;
    padding: 0 10px 1px;
    text-decoration: none;
    white-space: nowrap;
    .box-sizing(border-box);
    vertical-align: top;
    background-image: none;
  }

  .button.default,
  input.default[type="submit"],
  input.default[type="button"],
  button.default[type="submit"],
  .submit-row input.default {
    float: none;
    font-weight: bold;
  }
}