#content {
  textarea,
  input[type="text"],
  input[type="password"],
  input[type="email"],
  input[type="number"],
  input[type="search"],
  input[type="tel"],
  input[type="url"],
  input[type="file"],
  select {
    .box-shadow(0 1px 2px rgba(0, 0, 0, 0.07) inset);
    .border-radius(0);
    border-style: solid;
    border-width: 1px;
    padding: 3px 5px;
    margin: 1px;
    line-height: 15px;
    font-size: 13px;
    font-family: inherit;
    .box-sizing(border-box);

    &:focus {
      .box-shadow(0 1px 2px rgba(0, 0, 0, 0.1));
    }
  }

  select {
    padding: 3px;
  }

  input[type="file"] {
    padding: 3px 0;
    border: none;
    .box-shadow(none);
  }

  .form-row p {
    font-family: inherit;
    font-size: 13px;
    margin-bottom: 0;
    margin-top: 0;
    padding-bottom: 0;
    padding-top: 3px;
  }

  .errornote {
    border-width: 0 0 0 4px;
    border-style: solid;
    border-color: #FFC000;
    color: #FFC000;
    .box-shadow(0 1px 1px 0 rgba(0, 0, 0, 0.1));
    padding: 6px 12px;
    margin: 0 0 8px;
    font-size: 13px !important;
    font-weight: 400;
    background-image: none;
  }

  .errorlist {
    li {
      border-width: 0 0 0 4px;
      border-style: solid;
      border-color: #DD3D36;
      color: #DD3D36;
      .box-shadow(0 1px 1px 0 rgba(0, 0, 0, 0.1));
      padding: 6px 12px;
      margin: 0 0 8px;
      font-size: 13px !important;
      font-weight: 400;
      background-image: none;
    }
  }

  .errors {
    .errorlist {
      margin-top: 8px !important;

      li {
        .box-shadow(none);
        border-style: dashed dashed dashed solid;
        border-width: 1px 1px 1px 4px;
      }
    }
  }
}

@media screen and (max-width: 850px) {
  #content {
    textarea,
    input[type="text"],
    input[type="password"],
    input[type="email"],
    input[type="number"],
    input[type="search"],
    input[type="tel"],
    input[type="url"],
    input[type="file"],
    select {
      max-width: 530px;
    }
  }
}

@media screen and (max-width: 780px) {
  #content {
    textarea,
    input[type="text"],
    input[type="password"],
    input[type="email"],
    input[type="number"],
    input[type="search"],
    input[type="tel"],
    input[type="url"],
    input[type="file"],
    select {
      max-width: 390px;
    }
  }
}

@media screen and (max-width: 500px) {
  #content {
    textarea,
    input[type="text"],
    input[type="password"],
    input[type="email"],
    input[type="number"],
    input[type="search"],
    input[type="tel"],
    input[type="url"],
    input[type="file"],
    select {
      max-width: 260px;
    }
  }
}
