// menus

@menus-bg: #523F6D;

@menus-link-color: #FFF;
@menus-link-hover-color: #FFF;

@menus-top-elem-hover-bg: #A3B745;

@menus-icon-color: #ECE6F6;
@menus-icon-hover-color: #FFF;

@menus-top-elem-current-color: #FFF;
@menus-top-elem-current-bg: #A3B745;

@submenus-bg: #413256;

@submenus-link-color: #CBC5D3;
@submenus-link-hover-color: #A3B745;

@submenus-current-link-color: #FFF;

@submenus-head-color: #CBC5D3;

