@import "../mixins.less";
@import "forms.less";
@import "buttons.less";
@import "widgets.less";
@import "messages.less";
@import "bottombar.less";
@import "changelist.less";
@import "changeform.less";
@import "dashboard.less";
@import "login.less";

body.wp-no-breadcrumbs {
  .breadcrumbs { display: none !important; }
}

a,
button,
input[type="submit"] {
  outline: none;
}

#content {
  margin: 0 20px;
  padding: 10px 0 50px;

  li,
  dt,
  dd {
    font-size: 13px;
    line-height: 15px;
  }

  h1 {
    font-size: 23px;
    line-height: 29px;
    padding: 9px 15px 4px 0;
    font-weight: 400;

    a.add-new {
      font-size: 13px;
      font-weight: 600;
      margin-left: 4px;
      padding: 5px 10px;
      position: relative;
      text-decoration: none;
      top: -3px;
      border: 0;
    }
  }

  table {
    td,
    th {
      font-family: inherit;
      font-size: 13px;
      padding: 8px 10px;
    }

    thead th,
    thead td,
    tfoot th,
    tfoot td {
      background: none;
      border-style: solid;
      font-size: 14px;
      font-weight: 400;
    }

    thead th,
    thead td {
      border-width: 0 0 1px 0;
    }

    tfoot th,
    tfoot td {
      border-width: 1px 0 0 0;
    }

    tbody {
      th,
      td {
        border: none;
      }
    }
  }
}