#bottombar {
  position: fixed;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 40px;

  input[type="submit"],
  button[type="submit"],
  a.button {
    display: block;
    padding: 0 15px;
    float: left;
    margin-left: 5px;
    margin-top: 5px;
    height: 30px;
    font-size: 14px;
    font-weight: 600;
    line-height: 30px;
    border: 0;
    border-radius: 0;
    .box-shadow(none);
    text-shadow: none;
    opacity: 0.8;
    cursor: pointer;

    &:hover{
      opacity: 1;
    }

    .text {
      margin-left: 5px;
    }

    .fa.fa-caret-right {
      margin-left: 5px;
      margin-right: 5px;
      font-size: 0.8em;
    }
  }

  button + .deletelink {
    margin-left: 30px;
  }

  &.wp-narrow {
    input,
    button,
    a {
      padding: 0 5px;

      .text {
        display: none;
      }

      &.deletelink {
        margin-left: 5px;
      }
    }
  }
}

.wp-with-left-menu {
  #bottombar {
    left: @left-menu-width;
  }

  &.wp-folded {
    #bottombar {
      left: @folded-menu-width;
    }
  }
}

.popup {
  #bottombar {
    left: 0;
  }
}