// menus

@menus-bg: #738E96;

@menus-link-color: #FFF;
@menus-link-hover-color: #FFF;

@menus-top-elem-hover-bg: #9EBAA0;

@menus-icon-color: #F2FCFF;
@menus-icon-hover-color: @menus-link-hover-color;

@menus-top-elem-current-color: #FFF;
@menus-top-elem-current-bg: #9EBAA0;

@submenus-bg: #627C83;

@submenus-link-color: #D5DDDF;
@submenus-link-hover-color: #9EBAA0;

@submenus-current-link-color: #FFF;

@submenus-head-color: #D5DDDF;

