body.login {

  #wrapper {
    overflow: hidden;
  }

  #container {
    #content {
      .form-row {
        border: 0;
        padding-left: 0;
        padding-right: 0;
      }
    }
  }

  &.wp-with-left-menu {
    #container {
      margin-left: auto;
      width: 28em;
      position: relative;
      left: (@left-menu-width / 2);
    }

    &.wp-folded {
      #container {
        left: (@folded-menu-width / 2);
      }
    }

  }
}

@media screen and (max-width: 500px) {
  body.login {
    #container {
      width: 23em;

      .submit-row {
        padding-left: 7em;
      }
    }
  }
}
