#content {
  .datetimeshortcuts {
    font-size: 12px;

    a:last-child {
      display: inline-block;
      font-family: FontAwesome;
      font-style: normal;
      font-weight: normal;
      line-height: 1;

      img {
        display:none;
      }

      &:after {
        font-size: 14px;
        position: relative;
        top: 1px;
      }
    }
  }

  .vDateField {
    & + .datetimeshortcuts {
      a:last-child:after {
        content: "\f073";
      }
    }
  }

  .vTimeField {
    & + .datetimeshortcuts {
      a:last-child:after {
        content: "\f017";
      }
    }
  }

  .datetime {
    min-width: 260px;
    float: left;
    margin: 0;
    padding: 0;
    font-weight: 400;

    .vTimeField {
      margin-top: 3px;
    }
  }

  .selector {
    width: auto;
    max-width: 552px;

    .selector-available,
    .selector-chosen {
      width: 260px;

      h2 {
        border: none;
        padding-left: 0;
        padding-right: 0;
      }

      select {
        margin: 0;
        padding: 0;
        width: 258px;
        .box-sizing(content-box);

        &:focus {
          .box-shadow(0 1px 2px rgba(0, 0, 0, 0.07) inset);
        }
      }

      .selector-filter {
        border-style: solid;
        border-width: 1px 1px 0 1px;
        padding: 3px;

        label {
          width: 16px;
          padding: 4px 7px 4px 6px;
        }

        input {
          width: 220px;
        }
      }
    }

    ul.selector-chooser {
      background: none;
      height: 220px;

      .selector-add,
      .selector-remove {
        text-indent: 0;
        background: none;
        font-size: 0;
        line-height: 0;
        opacity: 0.5;

        &.active {
          opacity: 1;
        }

        &:after {
          display: inline-block;
          width: 16px;
          height: 16px;
          text-align: center;
          font-size: 20px;
          font-family: FontAwesome;
          line-height: 16px;
          font-weight: bold;
        }
      }

      .selector-add {
        &:after {
          content: "\f105";
        }
      }

      .selector-remove {
        &:after {
          content: "\f104";
        }
      }
    }

    a.selector-chooseall,
    a.selector-clearall {
      background: none;
      padding-right: 0;
      padding-left: 0;
      opacity: 0.5;
      font-size: 12px;

      &:after,
      &:before {
        display: inline-block;
        font-family: FontAwesome;
        font-size: 16px;
        font-weight: 400;
        position: relative;
        top: 1px;
        margin-left: 0.4em;
        margin-right: 0.4em;
      }

      &.active {
        opacity: 1;
      }
    }

    a.selector-chooseall {
      &:after {
        content: "\f101";
      }
    }

    a.selector-clearall {
      &:before {
        content: "\f100";
      }
    }

    &.stacked {
      max-width: 260px;

      .selector-chooser {
        height: 22px;
        margin-top: 10px;

        .selector-add {
          &:after {
            content: "\f107";
          }
        }

        .selector-remove {
          &:after {
            content: "\f106";
          }
        }
      }
    }
  }
}

.calendarbox,
.clockbox {
  border-width: 5px;
  border-style: solid;
  .box-shadow(@submenu-shadow);

  caption,
  h2 {
    font-size: 13px;
    padding: 1px 20px 5px;
    text-align: center;
  }

  .calendar-cancel {
    border: none;
    font-size: 12px;

    a {
      padding: 2px;
    }
  }
}

.calendarbox {
  .calendarnav-previous,
  .calendarnav-next {
    padding: 0;
    text-align: center;
    width: 19px;
    height: 19px;
    line-height: 19px;
    font-size: 18px;
    background: none;
  }

  .calendar {
    th {
      font-family: inherit;
      font-size: 12px;
      line-height: 15px;
      background: none;
      font-weight: 400;
    }

    td {
      border-style: dashed;
      border-width: 1px 0 0 1px;
      font-family: inherit;
      font-size: 13px;
      line-height: 15px;

      &:first-child {
        border-left: 0;
      }
    }
  }

  .calendar-shortcuts {
    font-size: 12px;
    line-height: 15px;
  }
}

.clockbox {
  .timelist {
    li {
      font-size: 12px;
      line-height: 18px;
      border-style: dashed;
      border-width: 1px 0 0;

      &:first-child {
        border-top: none;
      }
    }
  }
}

@media screen and (max-width: 669px) {
  #content .selector ul.selector-chooser {
    margin-top: 0;
    margin-bottom: 5px;
    height: 50px;
    width: 290px;
  }
}

@media screen and (max-width: 517px) {
  #content .datetime {
    margin-top: 5px;
  }
}

@media screen and (max-width: 500px) {
  #content .selector ul.selector-chooser {
    width: 250px;
  }
}
