{% load i18n wpadmin_menu_tags %}
{% spaceless %}
{% if is_user_allowed and not item.is_empty %}
	<li class="wp-menu-top{% if is_first %} wp-menu-top-first{% endif %}{% if is_last %} wp-menu-top-last{% endif %}{% if item.children %} wp-has-submenu{% endif %}{% if not item.enabled %} wp-disabled{% endif %}{% if not item.url %} wp-no-url{% endif %}{% if is_selected %} wp-menu-open{% else %} wp-menu-not-open{% endif %}{% if item.add_url %} wp-has-add-url{% endif %}" {% if item.css_styles %}style="{{ item.css_styles }}"{% endif %}>
		<div class="wp-menu-image"><a aria-label="{{ item.title }}" title="{{ item.description|default:'' }}" href="{% if item.url and item.enabled %}{{ item.url }}{% else %}javascript:;{% endif %}"><i class="fa fa-fw {{ icon }}"></i></a></div>
		<a href="{% if item.url and item.enabled %}{{ item.url }}{% else %}javascript:;{% endif %}"{% if item.description %} title="{{ item.description }}"{% endif %}{% if item.accesskey %} accesskey="{{ item.accesskey }}"{% endif %}>{{ item.title }}</a>
		{# Translators: This is already translated in Django #}
		{% if item.add_url %}<a title="{% trans "Add" %}" class="wp-add-url{% if request.path == item.add_url %} wp-current{% endif %}" href="{{ item.add_url }}">+</a>{% endif %}
		{% if item.children and item.enabled %}
		<div class="wp-submenu">
			<div class="wp-submenu-wrap">
				<div class="wp-submenu-head">{{ item.title }}</div>
				<ul>
					{% for child_item in item.children %}
						{% wpadmin_render_menu_item child_item forloop.first forloop.last %}
					{% endfor %}
				</ul>
			</div>
		</div>
		{% endif %}
	</li>
{% endif %}
{% endspaceless %}
