// menus

@menus-bg: #CF4944;

@menus-link-color: #FFF;
@menus-link-hover-color: #FFF;

@menus-top-elem-hover-bg: #DD823B;

@menus-icon-color: #FFF;
@menus-icon-hover-color: @menus-link-hover-color;

@menus-top-elem-current-color: #FFF;
@menus-top-elem-current-bg: #DD823B;

@submenus-bg: #BE3631;

@submenus-link-color: #F0C8C6;
@submenus-link-hover-color: #f7e3d3;

@submenus-current-link-color: #FFF;

@submenus-head-color: #F0C8C6;

@content-bg: #F1F1F1;

