// menus

@menus-bg: #59524C;

@menus-link-color: #FFF;
@menus-link-hover-color: #FFF;

@menus-top-elem-hover-bg: #C7A589;

@menus-icon-color: #F3F2F1;
@menus-icon-hover-color: #FFF;

@menus-top-elem-current-color: #FFF;
@menus-top-elem-current-bg: #C7A589;

@submenus-bg: #46403C;

@submenus-link-color: #CDCBC9;
@submenus-link-hover-color: #C7A589;

@submenus-current-link-color: #FFF;

@submenus-head-color: #CDCBC9;

