@content-bg: #F1F1F1;
@content-link-color: #0074A2;
@content-link-hover-color: #0099D5;

@actions-links-bg: rgba(0,0,0,0.05);

@messages-bg: #fff;
@messages-color: #444;

@box-bg: #fff;
@box-border: #E5E5E5;
@box-header-color: #222;
@box-header-border: #eee;

@table-bg: @box-bg;
@table-border: @box-border;
@table-header-color: #333;
@table-header-border: #E1E1E1;
@table-row1-bg: #f9f9f9;
@table-row2-bg: #fff;

@input-bg: #fff;
@input-border: #ddd;
@input-color: #333;
@input-focus-border: #999;

@button-bg: #F7F7F7;
@button-border: #ccc;
@button-color: #555;
@button-hover-bg: #FAFAFA;
@button-hover-border: #999;
@button-hover-color: #222;

@default-button-bg: fade(@menus-top-elem-current-bg, 80%);
@default-button-border: @menus-top-elem-current-bg;
@default-button-color: @menus-top-elem-current-color;
@default-button-hover-bg: @menus-top-elem-current-bg;
@default-button-hover-border: darken(@menus-top-elem-current-bg, 10%);
@default-button-hover-color: @menus-top-elem-current-color;

@help-color: #999;

