// menus

@menus-bg: #52ACCC;

@menus-link-color: #FFF;
@menus-link-hover-color: #FFF;

@menus-top-elem-hover-bg: #096484;

@menus-icon-color: #E5F8FF;
@menus-icon-hover-color: #FFF;

@menus-top-elem-current-color: #FFF;
@menus-top-elem-current-bg: #096484;

@submenus-bg: #4796B3;

@submenus-link-color: #E2ECF1;
@submenus-link-hover-color: #FFF;

@submenus-current-link-color: #FFF;

@submenus-head-color: #E2ECF1;

