#container {
  ul.messagelist {
    padding: 0 20px;

    li {
      border-width: 0 0 0 4px;
      border-style: solid;
      padding: 12px;
      .box-shadow(0 1px 1px 0 rgba(0, 0, 0, 0.1));
      margin: 10px 0 0;
      font-size: 13px;
      font-weight: 600;

      &.success {
        border-color: #7AD03A;
      }

      &.warning {
        border-color: #FFC000;
      }

      &.error {
        border-color: #DD3D36;
      }

      &.info {
        border-color: #52ACCC;
      }

      &:first-child {
        margin-top: 20px;
      }
    }
  }
}