// menus

@menus-bg: #E5E5E5;

@menus-link-color: #333;
@menus-link-hover-color: #FFF;

@menus-top-elem-hover-bg: #888;

@menus-icon-color: #999;
@menus-icon-hover-color: #CCC;

@menus-top-elem-current-color: #FFF;
@menus-top-elem-current-bg: #888;

@submenus-bg: #FFF;

@submenus-link-color: #686868;
@submenus-link-hover-color: #04A4CC;

@submenus-current-link-color: #333;

@submenus-head-color: #686868;

