// menus

@menus-bg: #222;

@menus-link-color: #EEE;
@menus-link-hover-color: #2EA2CC;

@menus-top-elem-hover-bg: #111;

@menus-icon-color: #999;
@menus-icon-hover-color: @menus-link-hover-color;

@menus-top-elem-current-color: #FFF;
@menus-top-elem-current-bg: #0074A2;

@submenus-bg: #333;

@submenus-link-color: #BBB;
@submenus-link-hover-color: @menus-link-hover-color;

@submenus-current-link-color: #FFF;

@submenus-head-color: #FFF;

