html {
  height: 100%;
  min-width: 360px;
}

body {
  font-family: "Open Sans",sans-serif;
  font-size: 13px;
  line-height: 1.4em;
  height: 100%;
}

#wrapper {
  height: auto;
  min-height: 100%;
  width: 100%;
  position: relative;
}

#container {
  min-width: 0;
}